@@ -103,7 +103,7 @@ class JinjaStaticRenderer(Core.Renderer):
 
         if (self.should_render_item(item, template)):
             self.reporter.verbose("\033[34m%s\033[37m last built at: %s\033[0m" % (item.get_file_path(), item.get_modified_time()))
-            return (template.render(data=item.get_content(), meta=item.get_metadata()), item)
+            return (template.render(data=item.get_content(), meta=item.get_metadata(), site=self.config["site_vars"]), item)
 
         return (False, item)
 
