@@ -22,14 +22,14 @@ class Wrangler():
             "input_dir": "site",
             "data_format": "json",
             "ignore": [".", "_"],
-            "site_vars":"env",
+            "site_vars":"site_vars",
             "verbose": "false",
             "force": "false",
             "nocache": "false",
             "item_class": "Page",
             "views": None
         },
-        "env": {
+        "site_vars": {
             "paths": {
                 "css": "assets/css",
                 "js": "assets/js",
